import {
  IonContent,
  IonHeader,
  IonLoading,
  IonPage,
  IonTitle,
  IonToast,
  IonToolbar,
} from "@ionic/react";
import { alertCircleOutline } from "ionicons/icons";
import { useEffect } from "react";
import useSWR from "swr";
import ListComponent from "../components/ListComponent";
import { fetcher } from "../lib/api";

interface Topic {
  blockId: string;
  name: string;
}

const LawListPage: React.FC = () => {
  const { data, error } = useSWR<Topic[]>(
    "/api/getTopicList?type=laws",
    fetcher
  );
  const isLoading = !data && !error;

  return (
    <IonPage>
      <IonHeader>
        <IonToolbar>
          <IonTitle>Leyes</IonTitle>
        </IonToolbar>
      </IonHeader>
      <IonContent fullscreen>
        <IonHeader collapse="condense">
          <IonToolbar>
            <IonTitle size="large">Leyes</IonTitle>
          </IonToolbar>
        </IonHeader>
        {data && <ListComponent laws={data.map((item) => item.name)} />}
        <IonLoading
          isOpen={isLoading}
          duration={isLoading ? 50 : undefined}
          message="Loading..."
        />
        <IonToast
          icon={alertCircleOutline}
          color="danger"
          isOpen={error}
          message="Failed to load items."
          duration={1500}
        />
      </IonContent>
    </IonPage>
  );
};

export default LawListPage;
